@@ -1,6 +1,6 @@
 package LLVM::Context;
 {
-  $LLVM::Context::VERSION = '0.01';
+  $LLVM::Context::VERSION = '0.02';
 }
 
 use strict;
@@ -12,11 +12,11 @@ LLVM::Context - LLVM context class
 
 =head1 VERSION
 
-version 0.01
+version 0.02
 
 =head1 DESCRIPTION
 
-Some description here...
+A C<LLVM::Context> is the top-level container for all LLVM global data.
 
 =head1 METHODS
 
