@@ -1,6 +1,6 @@
 package LLVM::Type;
 {
-  $LLVM::Type::VERSION = '0.01';
+  $LLVM::Type::VERSION = '0.02';
 }
 
 use strict;
@@ -12,11 +12,11 @@ LLVM::Type - LLVM type class
 
 =head1 VERSION
 
-version 0.01
+version 0.02
 
 =head1 DESCRIPTION
 
-Some description here...
+A C<LLVM::Type> represents the type of an individual L<LLVM::Value>.
 
 =head1 METHODS
 
